Datasets: Datasets for illustrating the functions in the SPEI package.
Description
Data used in the examples of the SPEI package: wichita dataset: monthly climate in Wichita (Kansas, lat=37.6475, elevation=402.6 m. a.s.l.) since January 1980; balance dataset: monthly climatic water balance (precipitation minus potential evapotranspiration) at eleven locations around the World, since January 1900.Usage
data(wichita)
data(balance)
source
The wichita data were obtained from the Global Historical Climatology Network (GHCN, http://www.ncdc.noaa.gov/oa/climate/ghcn-daily/. Data for the balance dataset were extracted from CRU TS V3.1 and from the 20th Century Reanalysis V2 dataset.References
S.M. Vicente-Serrano, S. Beguería, J.I. López-Moreno. 2010. A Multi-scalar drought index sensitive to global warming: The Standardized Precipitation Evapotranspiration Index – SPEI. Journal of Climate 23: 1696, DOI: 10.1175/2009JCLI2909.1.Examples
Run this codedata(wichita)
names(wichita)
summary(wichita)
data(balance)
summary(balance)
Run the code above in your browser using DataLab